package main

import (
	"context"
	"math/big"
	"os"

	"github.com/ethereum/go-ethereum/ethclient"
	"github.com/tendermint/tendermint/libs/log"
)

type Client struct {
	cliCtx      *ethclient.Client
	timerTicker *TimerTicker
	Logger      log.Logger
	Moniker     string
}

func NewClient(nodeRpc string) (*Client, error) {
	//cliCtx := context.NewCLIContext().WithNodeURI("tcp://192.168.3.200:26657")

	client, err := ethclient.Dial(nodeRpc)
	if err != nil {
		return nil, err
	}

	cli := Client{
		cliCtx: client,
		Logger: log.NewTMLogger(os.Stdout),
	}

	//cli.Moniker = status.NodeInfo.Moniker
	cli.timerTicker = NewTimerticker(&cli)

	cli.timerTicker.OnStart()

	return &cli, nil
}

// LatestBlockHeight returns the latest block height on the active chain
func (c *Client) LatestBlockHeight() (*big.Int, error) {

	header, err := c.cliCtx.HeaderByNumber(context.Background(), nil)
	if err != nil {
		return nil, err
	}

	return header.Number, nil
}

