package main

import (
	"fmt"
	"math/big"
	"time"
)

func (cli *Client) Monitor() {

	lastHeight := big.NewInt(0)
	lastTime := time.Now()

	apiErrTry := 0
	for {
		if apiErrTry > 5 {
			cli.Logger.Debug("query api failed, send alarm !!!", "try times", apiErrTry)

			alarm := AlarmInfo{
				AlarmType: Query,
				Detail:    fmt.Sprintf("query failed, try times: %v", apiErrTry),
				Time:      time.Now(),
			}
			cli.timerTicker.Data <- alarm
			apiErrTry = 0
		}

		height, err := cli.LatestBlockHeight()
		if err != nil {
			cli.Logger.Debug("faild to query block height")
			apiErrTry++
			time.Sleep(1 * time.Second)
			continue
		}

		if lastHeight.Cmp(height) == 0 {
			alarmTime := time.Now()
			elapse := alarmTime.Sub(lastTime).Seconds()
			if elapse < 120 {
				time.Sleep(5 * time.Second)
				continue
			}
			cli.Logger.Debug(fmt.Sprintf("Block height %v is not increased, take time: %v seconds.", height, elapse))
			alarm := AlarmInfo{
				AlarmType: BlockHeight,
				Detail:    fmt.Sprintf("Block %v doesnot increased, take time: %v seconds.", height, elapse),
				Time:      time.Now(),
			}
			cli.timerTicker.Data <- alarm
			time.Sleep(5 * time.Second)

			continue
		}
		lastHeight = height
		lastTime = time.Now()
		apiErrTry = 0
	}
}

